<!-- g documentation master file, created by
sphinx-quickstart on Tue Nov 21 20:49:41 2023.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->

# Welcome to g’s documentation!

# Indices and tables

* [Index](genindex.md)
* [Module Index](py-modindex.md)
* [Search Page](search.md)
